☰
lcode
0.5.9
Module dao
Modules
Statics
Functions
In crate lcode
?
Module
lcode
::
dao
source
·
[
−
]
Modules
query_topic_tags
save_info
Statics
DB
Functions
conn_db
get_question_index
Find the problem, if there are more than one, return multiple
get_question_index_exact
Find the problem, if there are more than one, return one
glob_db
Initialize the db connection
query_all_index